/**
 * <b>Object</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>newObject(<em>[value]</em>)</code>
 * </p>
 * <p>
 * Creates an object wrapper.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>value</b></td>
 * <td>Any value.</td>
 * </tr>
 * </table>
 * @type Object
 */
var Object = {
/**
 * <b>isPrototypeOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>prototype</em>.isPrototypeOf(<em>object</em>)</code>
 * </p>
 * <p>
 * Tests for an object in another object's prototype chain.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Object</i></td>
 * <td valign="top"><b>object</b></td>
 * <td>the object whose prototype chain will be searched</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Object</i></td>
 * <td valign="top"><b>prototype</b></td>
 * <td>  an object to be tested against each link in the prototype chain of the object  argument</td>
 * </tr>
 * </table>
 * @type Boolean
 */
isPrototypeOf: function() {},

/**
 * <b>toSource</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>obj</em>.toSource()</code>
 * </p>
 * <p>
 * Returns a string representing the source code of the object.
 * </p>
 * @type String
 */
toSource: function() {},

/**
 * <b>toLocaleString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>toLocaleString()</code>
 * </p>
 * <p>
 * Returns a string representing the object. This method is meant to be overriden by derived objects for locale-specific purposes.
 * </p>
 * @type String
 */
toLocaleString: function() {},

/**
 * <b>defineProperties</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.defineProperties(<em>obj</em>,<em>props</em>)</code>
 * </p>
 * <p>
 * Defines new or modifies existing properties directly on an object, returning the object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj props</b></td>
 * <td>The object on which to define or modify properties. An object whose own enumerable properties constitute descriptors for the properties to be defined or modified.</td>
 * </tr>
 * </table>
 * @type undefined
 * @static
 */
defineProperties: function() {},

/**
 * <b>unwatch</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>unwatch(<em>prop</em>)</code>
 * </p>
 * <p>
 * Removes a watchpoint set with the watch() method.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>prop</b></td>
 * <td>The name of a property of the object to stop watching.</td>
 * </tr>
 * </table>
 * @type undefined
 */
unwatch: function() {},

/**
 * <b>prototype</b>
 * <p>
 * Represents the Object prototype object.
 * </p>
 * @type Object
 * @static
 */
prototype: undefined,

/**
 * <b>getOwnPropertyDescriptor</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.getOwnPropertyDescriptor(<em>obj</em>,<em>prop</em>)</code>
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj prop</b></td>
 * <td>The object in which to look for the property. The name of the property whose description is to be retrieved</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
getOwnPropertyDescriptor: function() {},

/**
 * <b>getPrototypeOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.getPrototypeOf(<em>object</em>)</code>
 * </p>
 * <p>
 * Returns the prototype of the specified object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Object</i></td>
 * <td valign="top"><b>object</b></td>
 * <td>The object whose prototype is to be returned.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
getPrototypeOf: function() {},

/**
 * <b>seal</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.seal(<em>obj</em>)</code>
 * </p>
 * <p>
 * Seals an object, preventing new properties from being added to it and marking all existing properties as non-configurable. Values of present properties can still be changed as long as they are writable.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object which should be sealed.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
seal: function() {},

/**
 * <b>propertyIsEnumerable</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>obj</em>.propertyIsEnumerable(<em>prop</em>)</code>
 * </p>
 * <p>
 * Returns a Boolean indicating whether the specified property is enumerable.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>prop </b></td>
 * <td>The name of the property to test.</td>
 * </tr>
 * </table>
 * @type Boolean
 */
propertyIsEnumerable: function() {},

/**
 * <b>getOwnPropertyNames</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.getOwnPropertyNames(<em>obj</em>)</code>
 * </p>
 * <p>
 * Returns an array of all properties (enumerable or not) found upon a given object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object whose enumerable and non-enumerable own properties are to be returned.</td>
 * </tr>
 * </table>
 * @type Array
 * @static
 */
getOwnPropertyNames: function() {},

/**
 * <b>valueOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>valueOf()</code>
 * </p>
 * <p>
 * Returns the primitive value of the specified object
 * </p>
 * @type Object
 */
valueOf: function() {},

/**
 * <b>constructor</b>
 * <p>
 * Returns a reference to the Object function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name, but it isn't read only (except for primitive Boolean, Number or String values: 1, true, "read-only").
 * </p>
 * @type Function
 */
constructor: undefined,

/**
 * <b>keys</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.keys(<em>obj</em>)</code>
 * </p>
 * <p>
 * Returns an array of all own enumerable properties found upon a given object, in the same order as that provided by a for-in loop (the difference being that a for-in loop enumerates properties in the prototype chain as well).
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object whose enumerable own properties are to be returned.</td>
 * </tr>
 * </table>
 * @type Array
 * @static
 */
keys: function() {},

/**
 * <b>watch</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>object</em>.watch(<em>prop</em>,<em>handler</em>)</code>
 * </p>
 * <p>
 * Watches for a property to be assigned a value and runs a function when that occurs.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>prop</b></td>
 * <td>The name of a property of the object on which you wish to monitor changes.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>handler</b></td>
 * <td>A function to call when the specified property's value changes.</td>
 * </tr>
 * </table>
 * @type undefined
 */
watch: function() {},

/**
 * <b>eval</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>object</em>.eval(<em>string</em>)</code>
 * </p>
 * <p>
 * Evaluates a string of JavaScript code in the context of an object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>string</b></td>
 * <td>Any string representing a JavaScript expression, statement, or sequence of statements. The expression can include variables and properties of existing objects.</td>
 * </tr>
 * </table>
 * @type Object
 */
eval: function() {},

/**
 * <b>isFrozen</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.isFrozen(<em>obj</em>)</code>
 * </p>
 * <p>
 * Determine if an object is frozen.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object which should be checked.</td>
 * </tr>
 * </table>
 * @type Boolean
 * @static
 */
isFrozen: function() {},

/**
 * <b>isExtensible</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.isExtensible(<em>obj</em>)</code>
 * </p>
 * <p>
 * Determines if an object is extensible (whether it can have new properties added to it).
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object which should be checked.</td>
 * </tr>
 * </table>
 * @type Boolean
 * @static
 */
isExtensible: function() {},

/**
 * <b>create</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.create(<em>proto</em>[,<em>propertiesObject</em>])</code>
 * </p>
 * <p>
 * Creates a new object with the specified prototype object and properties.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Object</i></td>
 * <td valign="top"><b>proto propertiesObject</b></td>
 * <td>The object which should be the prototype of the newly-created object. If specified and not undefined, an object whose enumerable own properties (that is, those properties defined upon itself and not enumerable properties along its prototype chain) specify property descriptors to be added to the newly-created object, with the corresponding property names.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
create: function() {},

/**
 * <b>hasOwnProperty</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>obj</em>.hasOwnProperty(<em>prop</em>)</code>
 * </p>
 * <p>
 * Returns a boolean indicating whether the object has the specified property.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>prop</b></td>
 * <td>The name of the property to test.</td>
 * </tr>
 * </table>
 * @type Boolean
 */
hasOwnProperty: function() {},

/**
 * <b>isSealed</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.isSealed(<em>obj</em>)</code>
 * </p>
 * <p>
 * Determine if an object is sealed.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object which should be checked.</td>
 * </tr>
 * </table>
 * @type Boolean
 * @static
 */
isSealed: function() {},

/**
 * <b>freeze</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.freeze(<em>obj</em>)</code>
 * </p>
 * <p>
 * Freezes an object: that is, prevents new properties from being added to it; prevents existing properties from being removed; and prevents existing properties, or their enumerability, configurability, or writability, from being changed. In essence the object is made effectively immutable. The method returns the object being frozen.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object to freeze.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
freeze: function() {},

/**
 * <b>preventExtensions</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.preventExtensions(<em>obj</em>)</code>
 * </p>
 * <p>
 * Prevents new properties from ever being added to an object (i.e. prevents future extensions to the object).
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object which should be made non-extensible.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
preventExtensions: function() {},

/**
 * <b>toString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>object</em>.toString()</code>
 * </p>
 * <p>
 * Returns a string representing the object.
 * </p>
 * @type String
 */
toString: function() {},

/**
 * <b>defineProperty</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Object.defineProperty(<em>obj</em>,<em>prop</em>,<em>descriptor</em>)</code>
 * </p>
 * <p>
 * Defines a new property directly on an object, or modifies an existing property on an object, and returns the object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj prop descriptor</b></td>
 * <td>The object on which to define the property. The name of the property to be defined or modified. The descriptor for the property being defined or modified.</td>
 * </tr>
 * </table>
 * @type Object
 * @static
 */
defineProperty: function() {},

}
